Documentation
¶
Index ¶
- type SyncMap
- func (s *SyncMap[K, V]) Clear()
- func (s *SyncMap[K, V]) CompareAndDelete(key K, value V) bool
- func (s *SyncMap[K, V]) CompareAndSwap(key K, previous V, new V) bool
- func (s *SyncMap[K, V]) Delete(key K)
- func (s *SyncMap[K, V]) Load(key K) (V, bool)
- func (s *SyncMap[K, V]) LoadAndDelete(key K) (V, bool)
- func (s *SyncMap[K, V]) LoadOrStore(key K, value V) (V, bool)
- func (s *SyncMap[K, V]) Range(f func(key K, value V) bool)
- func (s *SyncMap[K, V]) Store(key K, value V)
- func (s *SyncMap[K, V]) Swap(key K, value V) (V, bool)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SyncMap ¶
type SyncMap[K comparable, V any] struct { // contains filtered or unexported fields }
func New ¶
func New[K comparable, V any](defaultValue V) *SyncMap[K, V]
func (*SyncMap[K, V]) Clear ¶
func (s *SyncMap[K, V]) Clear()
Clear deletes all the entries, resulting in an empty Map.
Added in go1.23
func (*SyncMap[K, V]) CompareAndDelete ¶
CompareAndDelete deletes the entry for key if its value is equal to old. The old value must be of a comparable type.
If there is no current value for key in the map, CompareAndDelete returns false (even if the old value is the nil interface value).
Added in go1.20
func (*SyncMap[K, V]) CompareAndSwap ¶
CompareAndSwap swaps the old and new values for key if the value stored in the map is equal to old. The old value must be of a comparable type.
Added in go1.20
func (*SyncMap[K, V]) Delete ¶
func (s *SyncMap[K, V]) Delete(key K)
Delete deletes the value for a key. If the key is not in the map, Delete does nothing.
Added in go1.9
func (*SyncMap[K, V]) Load ¶
Load returns the value stored in the map for a key, or nil if no value is present. The ok result indicates whether value was found in the map.
Added in go1.9
func (*SyncMap[K, V]) LoadAndDelete ¶
LoadAndDelete deletes the value for a key, returning the previous value if any. The loaded result reports whether the key was present.
Added in go1.15
func (*SyncMap[K, V]) LoadOrStore ¶
LoadOrStore returns the existing value for the key if present. Otherwise, it stores and returns the given value. The loaded result is true if the value was loaded, false if stored.
Added in go1.9
func (*SyncMap[K, V]) Range ¶
Range calls f sequentially for each key and value present in the map. If f returns false, range stops the iteration.
Range does not necessarily correspond to any consistent snapshot of the Map's contents: no key will be visited more than once, but if the value for any key is stored or deleted concurrently (including by f), Range may reflect any mapping for that key from any point during the Range call. Range does not block other methods on the receiver; even f itself may call any method on m.
Range may be O(N) with the number of elements in the map even if f returns false after a constant number of calls.
Added in go1.9